# omni-belt

[![Build Status](https://travis-ci.com/felixludos/omni-belt.svg?branch=master)](https://travis-ci.com/felixludos/omni-belt)

This is a simple tool belt containing pure python utilities for downstream projects.
